<?php

/**
* Principal Controller
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 		Alexandria_Mail_Builder
* @subpackage 	Alexandria_Mail_Builder/admin/controllers
*/

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class MainEmailBuilderController {

	static function intiBuilder($lang) {

		global $sitepress;

	    // lang from your javascript
		$lang_code = $lang != '' ? $lang : 'es';

	    // switch to the desired language
		$sitepress->switch_lang($lang_code);

		$data = [
			'interlocutors' => []
		];

		$args = array(  
			'post_type' => 'interlocutors_email',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'suppress_filters' => 0,
			'orderby' => 'title', 
			'order' => 'ASC'
		);

		$data['interlocutors'] = get_posts($args);

		do_action('alexandria_mail_show_main_template', 'steps_container', $data);

	} // end index


	static function getMailMetadata($lang) {

		global $sitepress;

	    // lang from your javascript
		$lang_code = $lang != '' ? $lang : 'es';

	    // switch to the desired language
		$sitepress->switch_lang($lang_code);

		$interlocutor_id = $_POST['interlocutor'];
		$situation_id = $_POST['situation'];
		$tono_id = $_POST['tono'];

		$data = [];

		$args = array(  
			'post_type' => 'emails',
			'post_status' => 'publish',
			'numberposts' => 1,
			'suppress_filters' => 0,
			'meta_query' => array(
				'relation' => 'AND',
				array(
					'key'   => '_interlocutor_email',
					'value' => intval($interlocutor_id),
					'meta_compare'	=> '='
				),
				array(
					'key'   => '_situation_email',
					'value' => intval($situation_id),
					'meta_compare'	=> '='
				),
				array(
					'key'   => '_tono_email',
					'value' => intval($tono_id),
					'meta_compare'	=> '='
				),
			)
		);

		$email = get_posts($args);

		if(isset($email)) {

			$metadata_array = array(
				'soliloquios' => [],
				'gran_ideas_email' => [],
				'arguments_email' => [],
				'call_to_action' => [],
				
				'gran_ideas_pitch' => [],
				'arguments_pitch' => [],
				'content_boxes' => [],
				'engagement_boxes' => [],
				'ingredients' => [],

				'examples_email' => []
			);

			$gran_ideas_email = get_post_meta( $email[0]->ID, '_gran_idea_email', true );
			$arguments_email = get_post_meta( $email[0]->ID, '_arguments_email', true );
			$content_boxes = get_post_meta( $email[0]->ID, '_content_boxes', true );
			$engagement_boxes = get_post_meta( $email[0]->ID, '_engagement_boxes', true );
			$ingredients = get_post_meta( $email[0]->ID, '_ingredients', true );

			$soliloquios = get_post_meta( $email[0]->ID, '_soliloquios_email', true );
			$gran_ideas_pitch = get_post_meta( $email[0]->ID, '_gran_idea_pitch', true );
			$arguments_pitch = get_post_meta( $email[0]->ID, '_arguments_pitch', true );
			$call_to_action = get_post_meta( $email[0]->ID, '_call_to_action', true );

			$examples = get_post_meta( $email[0]->ID, '_examples_email', true );

			foreach ($gran_ideas_email as $index => $value) {
				$metadata_array['gran_ideas_email'][$index] = get_post($value);
			}

			foreach ($arguments_email as $index => $value) {
				$post = get_post($value);
				$metadata_array['arguments_email'][$index] = get_post($value);
				$metadata_array['arguments_email'][$index]->content = apply_filters( 'the_content', $post->post_content );
			}

			foreach ($content_boxes as $index => $value) {
				$metadata_array['content_boxes'][$index] = get_post($value);
			}

			foreach ($engagement_boxes as $index => $value) {
				$metadata_array['engagement_boxes'][$index] = get_post($value);
			}

			foreach ($ingredients as $index => $value) {
				$metadata_array['ingredients'][$index] = get_post($value);
			}
			
			foreach ($soliloquios as $index => $value) {
				$metadata_array['soliloquios'][$index] = get_post($value);
			}

			foreach ($gran_ideas_pitch as $index => $value) {
				$metadata_array['gran_ideas_pitch'][$index] = get_post($value);
			}

			foreach ($arguments_pitch as $index => $value) {
				$post = get_post($value);
				$metadata_array['arguments_pitch'][$index] = get_post($value);
				$metadata_array['arguments_pitch'][$index]->content = apply_filters( 'the_content', $post->post_content );
			}

			foreach ($call_to_action as $index => $value) {
				$metadata_array['call_to_action'][$index] = get_post($value);
			}

			foreach ($examples as $index => $value) {
				$post = get_post($value);
				$metadata_array['examples_email'][$index] = get_post($value);
				$metadata_array['examples_email'][$index]->content = apply_filters( 'the_content', $post->post_content );
			}

			$data['email'] = $email[0];
			$data['metadata'] = $metadata_array;
		}

		echo json_encode($data);
		exit;
	}

}